@@ -45,7 +45,7 @@ EGwSendOptions *opts = NULL;
 gboolean changed = FALSE;
 EAccount *account;
 
-GtkWidget* org_gnome_send_options (EPlugin *epl, EConfigHookItemFactoryData *data);
+GtkWidget * org_gnome_send_options (EPlugin *epl, EConfigHookItemFactoryData *data);
 void send_options_commit (EPlugin *epl, EConfigHookItemFactoryData *data);
 void send_options_changed (EPlugin *epl, EConfigHookItemFactoryData *data);
 void send_options_abort (EPlugin *epl, EConfigHookItemFactoryData *data);
@@ -62,7 +62,7 @@ get_cnc (GtkWindow *parent_window)
 	const gchar *poa_address;
 	const gchar *scheme;
 	gboolean remember;
-	guint16 soap_port;
+	gchar *soap_port;
 
 	url = camel_url_new (account->source->url, NULL);
 	if (url == NULL)
@@ -89,7 +89,7 @@ get_cnc (GtkWindow *parent_window)
 
 	key =  g_strdup_printf ("groupwise://%s@%s/", url->user, poa_address);
 
-	uri = g_strdup_printf ("%s://%s:%u/soap", scheme, poa_address, soap_port);
+	uri = g_strdup_printf ("%s://%s:%s/soap", scheme, poa_address, soap_port);
 
 	failed_auth = "";
 	cnc = NULL;
@@ -100,7 +100,7 @@ get_cnc (GtkWindow *parent_window)
 	password = e_passwords_get_password (NULL, key);
 	if (!password)
 		password = e_passwords_ask_password (prompt, NULL, key, prompt,
-				E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET, &remember, parent_window);
+				E_PASSWORDS_REMEMBER_FOREVER | E_PASSWORDS_SECRET, &remember, parent_window);
 	g_free (prompt);
 
 	cnc = e_gw_connection_new (uri, url->user, password);
@@ -152,7 +152,8 @@ e_send_options_load_status_options (ESendOptionsStatusTracking *sopts,
 }
 
 static void
-e_send_options_load_default_data (EGwSendOptions *opts, ESendOptionsDialog *sod)
+e_send_options_load_default_data (EGwSendOptions *opts,
+                                  ESendOptionsDialog *sod)
 {
 	EGwSendOptionsGeneral *ggopts;
 	EGwSendOptionsStatusTracking *gmopts;
@@ -171,7 +172,8 @@ e_send_options_load_default_data (EGwSendOptions *opts, ESendOptionsDialog *sod)
 }
 
 static void
-e_send_options_clicked_cb (GtkWidget *button, gpointer data)
+e_send_options_clicked_cb (GtkWidget *button,
+                           gpointer data)
 {
 	EGwConnectionStatus status;
 	account = (EAccount *) data;
@@ -203,7 +205,8 @@ e_send_options_clicked_cb (GtkWidget *button, gpointer data)
 }
 
 GtkWidget *
-org_gnome_send_options (EPlugin *epl, EConfigHookItemFactoryData *data)
+org_gnome_send_options (EPlugin *epl,
+                        EConfigHookItemFactoryData *data)
 {
 	EMConfigTargetAccount *target_account;
 	GtkWidget *frame, *button, *label, *vbox;
@@ -538,7 +541,8 @@ add_send_options_to_source (EGwSendOptions *n_opts)
 }
 
 void
-send_options_commit (EPlugin *epl, EConfigHookItemFactoryData *data)
+send_options_commit (EPlugin *epl,
+                     EConfigHookItemFactoryData *data)
 {
 	EGwSendOptions *n_opts;
 	EGwConnectionStatus status = E_GW_CONNECTION_STATUS_OK;
@@ -564,12 +568,14 @@ send_options_commit (EPlugin *epl, EConfigHookItemFactoryData *data)
 }
 
 void
-send_options_changed (EPlugin *epl, EConfigHookItemFactoryData *data)
+send_options_changed (EPlugin *epl,
+                      EConfigHookItemFactoryData *data)
 {
 }
 
 void
-send_options_abort (EPlugin *epl, EConfigHookItemFactoryData *data)
+send_options_abort (EPlugin *epl,
+                    EConfigHookItemFactoryData *data)
 {
 	send_options_finalize ();
 }
